## README

Documentation for the *pqcprep* package is hosted [here](https://david-f-amorim.github.io/PQC_function_evaluation/pqcprep.html). The project GitHub can be found 
[here](https://github.com/david-f-amorim/PQC_function_evaluation).
 